@@ -16,32 +16,33 @@
 """
 from nonebot.matcher import Matcher
 from nonebot.typing import T_State
-from nonebot.params import CommandArg,ArgPlainText,RegexGroup,Arg,Command,RawCommand
+from nonebot.params import CommandArg,ArgPlainText,RegexGroup,Arg,RawCommand,CommandStart
 
 from typing import Tuple,Union,List
 from time import sleep
+import asyncio
+
 from .config import *
 from .utils import *
 from .command import *
-from .l4d2_image.steam import url_to_byte
+from .l4d2_image.steam import url_to_byte,url_to_byte_name
 from nonebot.plugin import PluginMetadata
 from .l4d2_data import sq_L4D2
-from nonebot import get_driver
+from nonebot import get_driver, require
 from .l4d2_image.vtfs import img_to_vtf
 from .l4d2_queries.ohter import load_josn
-from .l4d2_queries.qqgroup import write_json,ip_anne_list
+from .l4d2_queries.qqgroup import write_json
 from .l4d2_file import updown_l4d2_vpk,all_zip_to_one
-from .l4d2_queries.maps import seach_map,map_dict_to_str
+
 from .txt_to_img import mode_txt_to_img
 # from .l4d2_server import RCONClient
-from nonebot import get_bot, require
-# from .l4d2_server import web,webUI
+# from .l4d2_web import web,webUI
 scheduler = require("nonebot_plugin_apscheduler").scheduler
 
 driver = get_driver()
 
 
-__version__ = "0.3.6"
+__version__ = "0.4.1"
 __plugin_meta__ = PluginMetadata(
     name="求生之路小助手",
     description='群内对有关求生之路的查询和操作',
@@ -374,47 +375,6 @@ async def _(args:Message = CommandArg()):
         message = await write_json(msg)
         await updata.finish(message)
   
-@read_ip.handle()
-async def _():
-    img = await qq_ip_queries_pic(ip_anne_list)
-    if img == None:
-        return "电信服的地址请加主群自行填写哦"
-    await read_ip.finish(MessageSegment.image(img))
-
-@tan_jian.handle()
-async def _(event:MessageEvent):
-    await tan_jian.send('正在寻找牢房...')
-    msg = await get_tan_jian(ip_anne_list,1)
-    await tan_jian.finish(msg)
-
-@get_ip.handle()
-async def _(command: str = RawCommand(),args:Message = CommandArg()):
-    logger.info(command)
-    msg:str = args.extract_plain_text()
-    if not msg:
-        # 以图片输出全部当前
-        this_ips = ALL_HOST[command]
-        ip_list = []
-        for one_ip in this_ips:
-            host,port = split_maohao(one_ip['ip'])
-            ip_list.append((one_ip['id'],host,port))
-        img = await qq_ip_queries_pic(ip_list)
-        if img:
-            await read_ip.finish(MessageSegment.image(img)) 
-        else:
-            await read_ip.finish("服务器无响应")
-    else:
-        message = await json_server_to_tag_dict(command,msg)
-        if len(message) == 0:
-            # 关键词不匹配，忽略
-            return
-        ip = str(message['ip'])
-        logger.info(ip)
-        try:
-            msg= await get_anne_server_ip(ip)
-            await get_ip.finish(msg)
-        except OSError:
-            await get_ip.finish('服务器无响应')
 
             
 @vtf_make.handle()
@@ -442,16 +402,6 @@ async def _(bot:Bot,event:MessageEvent,state:T_State,tag = Arg("image")):
     await upload_file(bot, event, img_bytes, file_name)
 
 
-@prison.handle()
-async def _(event:MessageEvent):
-    msg = await get_tan_jian(ip_anne_list,2)
-    await tan_jian.finish(msg)
-
-@open_prison.handle()
-async def _(event:MessageEvent):
-
-    msg = await get_tan_jian(ip_anne_list,3)
-    await tan_jian.finish(msg)
 
 @smx_file.handle()
 async def _():
@@ -465,18 +415,126 @@ async def _():
     await find_vpk.finish(mode_txt_to_img(mes,msg))
     
 @search_api.handle()
-async def _(args:Message = CommandArg()):
+async def _(state:T_State,event:GroupMessageEvent,args:Message = CommandArg()):
     msg:str = args.extract_plain_text()
     # if msg.startswith('代码'):
         # 建图代码返回三方图信息
-    data = await seach_map(msg,l4_master[0],l4_key)
+    data = await seach_map(msg,l4_qq,l4_key)
     # else:
     if type(data) == str:
         await search_api.finish(data)
     else:
-        await search_api.finish(await map_dict_to_str(data))
+        state['maps'] = data
+        await search_api.send(await map_dict_to_str(data))
         
+@search_api.got("is_sure",prompt='如果需要上传，请发送 "yes"')    
+async def _(bot:Bot,event:GroupMessageEvent,state:T_State):
+    is_sure = str(state["is_sure"])
+    if is_sure == 'yes':
+        data_dict:dict = state['maps'][0]
+        if type(data_dict) == dict:
+            logger.info('开始上传')
+            if l4_only:
+                data_file,file_name = await url_to_byte_name(data_dict['url'],'htp')
+            else:
+                data_file,file_name = await url_to_byte_name(data_dict['url'])
+            if data_file:
+                await search_api.send('获取地址成功，尝试上传')
+                await upload_file(bot, event, data_file, file_name)
+            else:
+                await search_api.send('出错了，原因是下载链接不存在')
+        else:
+            logger.info('开始上传')
+            for data_one in data_dict:
+                data_file,file_name = await url_to_byte_name(data_one['url'])
+                await all_zip_to_one
+                await upload_file(bot, event, data_file, file_name)
+    else:
+        await search_api.finish('已取消上传')
+        
+
+@driver.on_startup
+async def _():
+    global ALL_HOST
+    global ANNE_IP
+    if l4_tag == None:
+        pass
+    else:
+        ALL_HOST.update(await seach_map(l4_tag,l4_qq,l4_key,'ip'))
+        def count_ips(ip_dict:dict):
+            for key, value in ip_dict.items():
+                if key == 'error_':
+                    continue
+                count = len(value)
+                logger.info(f'已加载：{key} | {count}个')
+                if key == '云':
+                    ANNE_IP = {key:value}
+        count_ips(ALL_HOST)
+        ip_anne_list=[] 
+        try:
+            ips = ALL_HOST['云']
+            ip_anne_list = []
+            for one_ip in ips:
+                host,port = split_maohao(one_ip['ip'])
+                ip_anne_list.append((one_ip['id'],host,port))
+        except KeyError:
+            pass
+    get_ip = on_command('anne',aliases=server_key(),priority=80,block=True)
+    @get_ip.handle()
+    async def _(start:str = CommandStart(),command: str = RawCommand(),args:Message = CommandArg(),):
+        if start:
+            command.replace(start,'')
+        if command == 'anne':
+            command = '云'
+        msg:str = args.extract_plain_text()
+        if not msg:
+            # 以图片输出全部当前
+            this_ips = ALL_HOST[command]
+            ip_list = []
+            for one_ip in this_ips:
+                host,port = split_maohao(one_ip['ip'])
+                ip_list.append((one_ip['id'],host,port))
+            img = await qq_ip_queries_pic(ip_list)
+            if img:
+                await get_ip.finish(MessageSegment.image(img)) 
+            else:
+                await get_ip.finish("服务器无响应")
+        else:
+            if not msg[0].isdigit():
+                if any(mode in msg for mode in gamemode_list):
+                    pass
+                else:
+                    return
+            message = await json_server_to_tag_dict(command,msg)
+            if len(message) == 0:
+                # 关键词不匹配，忽略
+                return
+            ip = str(message['ip'])
+            logger.info(ip)
+            try:
+                msg= await get_anne_server_ip(ip)
+                await get_ip.finish(msg)
+            except (OSError,asyncio.exceptions.TimeoutError):
+                await get_ip.finish('服务器无响应')
+                
+    @tan_jian.handle()
+    async def _(event:MessageEvent):
+        await tan_jian.send('正在寻找牢房...')
+        msg = await get_tan_jian(ip_anne_list,1)
+        await tan_jian.finish(msg)  
+        
+    @prison.handle()
+    async def _(event:MessageEvent):
+        msg = await get_tan_jian(ip_anne_list,2)
+        await tan_jian.finish(msg)
+
+    @open_prison.handle()
+    async def _(event:MessageEvent):
+
+        msg = await get_tan_jian(ip_anne_list,3)
+        await tan_jian.finish(msg)
     
+            
 @driver.on_shutdown
 async def close_db():
     """关闭数据库"""
