@@ -1,6 +1,7 @@
-import nonebot
+
 from nonebot.permission import SUPERUSER
 from nonebot import get_driver
+from nonebot.log import logger
 from nonebot.adapters.onebot.v11.permission import (
     GROUP_ADMIN,
     GROUP_OWNER,
@@ -10,22 +11,24 @@ from pathlib import Path
 from typing import List
 import ast
 import platform
+import os
 try:
     import ujson as json
 except:
     import json
-    
+from .l4d2_queries.ohter import ALL_HOST    
+from .l4d2_queries.api import seach_map,map_dict_to_str
 file_format = (".vpk",".zip",".7z",'rar')
 # 权限
 
 driver = get_driver()
+COMMAND_START = list[driver.config.command_start]
 try:
     NICKNAME: str = list(driver.config.nickname)[0]
 except Exception:
     NICKNAME = 'bot'
 CHECK_FILE:int = 0
-ANNE_IP:dict = json.load(open(Path(__file__).parent.joinpath(
-        'data/L4D2/l4d2.json'), "r", encoding="utf8"))
+
 
 reMaster = SUPERUSER | GROUP_OWNER 
 Master = SUPERUSER | GROUP_ADMIN | GROUP_OWNER 
@@ -80,14 +83,17 @@ try:
     l4_master: List[str] = driver.config.l4_master
 except:
     l4_master: List[str] = ['114514']
-   
-    
 try:
-    l4_proxies: set = {
-            'http://':driver.config.l4_proxies
-        }
+    l4_qq: str = list(driver.config.superusers)[0]
 except:
-    l4_proxies = ''
+    l4_qq: str =  ''
+    
+# try:
+#     l4_proxies: set = {
+#             'http://':driver.config.l4_proxies
+#         }
+# except:
+#     l4_proxies = ''
 
 try:
     l4_style:str = driver.config.l4_style
@@ -99,9 +105,19 @@ try:
 except:
     l4_key:str = ""
 
-l4_list = [l4_file, l4_steamid, l4_host, l4_port, l4_rcon, l4_master]
-l4_list = [ast.literal_eval(i) if isinstance(i, str) else i for i in l4_list]
-l4_file, l4_steamid, l4_host, l4_port, l4_rcon, l4_master = l4_list
+try:
+    l4_tag:list = driver.config.l4_tag
+except:
+    l4_tag = None
+# 强制转list
+if type(l4_tag) == str or list:
+    l4_list = [l4_file, l4_steamid, l4_host, l4_port, l4_rcon, l4_master,l4_tag]
+    l4_list = [ast.literal_eval(i) if isinstance(i, str) else i for i in l4_list]
+    l4_file, l4_steamid, l4_host, l4_port, l4_rcon, l4_master, l4_tag= l4_list
+else:
+    l4_list = [l4_file, l4_steamid, l4_host, l4_port, l4_rcon, l4_master]
+    l4_list = [ast.literal_eval(i) if isinstance(i, str) else i for i in l4_list]
+    l4_file, l4_steamid, l4_host, l4_port, l4_rcon, l4_master= l4_list            
         
 '''
 地图路径
@@ -157,6 +173,18 @@ tables_columns = {
 # 求生anne服务器
 anne_url = "https://server.trygek.com/"
 
+gamemode_list = [
+    '战役',
+    '多特',
+    '写专',
+    'anne',
+    '药抗',
+    '包抗',
+    '绝境',
+    '死专',
+    'ast',
+    '清道夫',
+]
 
 # 系统
 if platform.system() == 'Windows':
@@ -165,6 +193,9 @@ elif platform.system() == 'Linux':
     systems:str = 'linux'
 else:
     systems:str = 'others'
+ANNE_IP = {}
 
-
-
+try:
+    os.remove(Path().parent.joinpath('data/L4D2/l4d2.yml'))
+except:
+    pass
