@@ -51,37 +51,48 @@ async def qq_ip_queries(msg:List[tuple]):
         messsage += '序号、'+ str(number) + '\n' + msg1 + msg2 + '--------------------\n'
     return messsage
             
-async def qq_ip_queries_pic(msg:list):
-    """输入一个ip的三元元组组成的列表，返回一个输出消息的图片"""
+async def qq_ip_queries_pic(msg: list):
     msg_list = []
     pic = None
+    tasks = []  # 用来保存异步任务
     if msg != []:
         for i in msg:
             try:
-                number,host,port = i
+                number, host, port = i
             except ValueError:
-                number,qqgroup,host,port = i
+                number, qqgroup, host, port = i
             finally:
-                try:
-                    msg2 = await player_queries_anne_dict(host,port)
-                    msg1 = await queries_dict(host,port)
-                    msg1.update({'Players':msg2})
-                    msg1.update({'number':number})
-                    # msg1是一行数据完整的字典
-                    msg_list.append(msg1)
-                except errors:
-                    continue
+                # 将异步任务添加到任务列表中
+                tasks.append(asyncio.create_task(process_message(number, host, port, msg_list)))
+        # 等待所有异步任务完成
+        await asyncio.gather(*tasks)
+        # 对msg_list按照number顺序排序
+        msg_list = sorted(msg_list, key=lambda x: x['number'])
         pic = await server_ip_pic(msg_list)
-    if pic == None:
+    if pic is None:
         return None
     return pic
+
+
+
+async def process_message(number, host, port, msg_list):
+    try:
+        msg2 = await player_queries_anne_dict(host, port)
+        msg1 = await queries_dict(host, port)
+        msg1.update({'Players':msg2})
+        msg1.update({'number':number})
+        msg_list.append(msg1)
+    except errors:
+        pass  # 忽略异常，继续下一次循环
+
+
     
 async def get_tan_jian(msg:List[tuple],mode:int):
     """获取anne列表抽一个"""
     msg_list = []
-    rank = 0
+    random.shuffle(msg)
     for i in msg:
-        number,host,port = i 
+        number,host,port = i
         try:
             if mode == 1:
                 # 探监
@@ -134,11 +145,14 @@ async def get_tan_jian(msg:List[tuple],mode:int):
                     msg_list.append(msg1)
         except errors:
             continue
+        if msg_list != []:
+            break
     # 随机选一个牢房
+    logger.info(msg_list)
     if len(msg_list) == 0:
         return '暂时没有这种牢房捏'
     logger.info(len(msg_list))
-    mse = random.choice(msg_list)
+    mse = msg_list[0]
     message:str = ''
     if mode == 1:
         ranks = mse['ranks']
@@ -171,6 +185,8 @@ async def get_tan_jian(msg:List[tuple],mode:int):
     message += 'connect ' + mse['ip']
     return message
 
+
+
 async def get_server_ip(number):
     group,host,port = await si.query_number(number)
     try:
@@ -250,12 +266,3 @@ async def write_json(data_str:str):
                         return '删除成功喵'
                 return '序号不正确，请输入【求生更新 删除 腐竹 序号】'
         return '腐竹名不存在，请输入【求生更新 删除 腐竹 序号】'    
-ip_anne_list=[] 
-try:
-    ips = ALL_HOST['云']
-    ip_anne_list = []
-    for one_ip in ips:
-        host,port = split_maohao(one_ip['ip'])
-        ip_anne_list.append((one_ip['id'],host,port))
-except KeyError:
-    pass
\ No newline at end of file
